# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: connection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='connection.proto',
  package='connection',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10\x63onnection.proto\x12\nconnection\"\x07\n\x05\x45mpty\"?\n\x19GetNodeStructuresResponse\x12\x10\n\x08serverId\x18\x01 \x01(\t\x12\x10\n\x08jsonData\x18\x02 \x01(\t\"E\n\x1fGetCurrentExistingNodesResponse\x12\x10\n\x08serverId\x18\x01 \x01(\t\x12\x10\n\x08jsonData\x18\x02 \x01(\t\"G\n\x19\x43reateNodeInstanceRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08nodePath\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"T\n\x1a\x43reateNodeInstanceResponse\x12\x10\n\x08serverId\x18\x01 \x01(\t\x12\x0e\n\x06result\x18\x02 \x01(\x08\x12\x14\n\x0c\x65rrorMessage\x18\x03 \x01(\t\"=\n\x17UpdatePortValuesRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0eportValuesJson\x18\x02 \x01(\t\"R\n\x18UpdatePortValuesResponse\x12\x10\n\x08serverId\x18\x01 \x01(\t\x12\x0e\n\x06result\x18\x02 \x01(\x08\x12\x14\n\x0c\x65rrorMessage\x18\x03 \x01(\t\"O\n\x12\x45xecuteNodeRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08portName\x18\x02 \x01(\t\x12\x1b\n\x13inputPortValuesJson\x18\x03 \x01(\t\"\x88\x01\n\x13\x45xecuteNodeResponse\x12\x10\n\x08serverId\x18\x01 \x01(\t\x12\x0e\n\x06result\x18\x02 \x01(\x08\x12\x14\n\x0c\x65rrorMessage\x18\x03 \x01(\t\x12\x1b\n\x13localPortValuesJson\x18\x04 \x01(\t\x12\x1c\n\x14outputPortValuesJson\x18\x05 \x01(\t\"\x1f\n\x11RemoveNodeRequest\x12\n\n\x02id\x18\x01 \x01(\t\"L\n\x12RemoveNodeResponse\x12\x10\n\x08serverId\x18\x01 \x01(\t\x12\x0e\n\x06result\x18\x02 \x01(\x08\x12\x14\n\x0c\x65rrorMessage\x18\x03 \x01(\t\",\n\x10ResourceMetaData\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"\x1f\n\x0cResourceData\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"m\n\x13SendResourceRequest\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.connection.ResourceMetaData\x12&\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x18.connection.ResourceData\"8\n\x14SendResourceResponse\x12\x10\n\x08serverId\x18\x01 \x01(\t\x12\x0e\n\x06result\x18\x02 \x01(\x08\"0\n\x12GetResourceRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06remove\x18\x02 \x01(\x08\"\x7f\n\x13GetResourceResponse\x12\x10\n\x08serverId\x18\x01 \x01(\t\x12.\n\x08metadata\x18\x02 \x01(\x0b\x32\x1c.connection.ResourceMetaData\x12&\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x18.connection.ResourceData\"$\n\x16ReleaseResourceRequest\x12\n\n\x02id\x18\x01 \x01(\t\"Q\n\x17ReleaseResourceResponse\x12\x10\n\x08serverId\x18\x01 \x01(\t\x12\x0e\n\x06result\x18\x02 \x01(\x08\x12\x14\n\x0c\x65rrorMessage\x18\x03 \x01(\t2\xac\x06\n\x0e\x43onnectionGrpc\x12O\n\x11GetNodeStructures\x12\x11.connection.Empty\x1a%.connection.GetNodeStructuresResponse\"\x00\x12[\n\x17GetCurrentExistingNodes\x12\x11.connection.Empty\x1a+.connection.GetCurrentExistingNodesResponse\"\x00\x12\x65\n\x12\x43reateNodeInstance\x12%.connection.CreateNodeInstanceRequest\x1a&.connection.CreateNodeInstanceResponse\"\x00\x12_\n\x10UpdatePortValues\x12#.connection.UpdatePortValuesRequest\x1a$.connection.UpdatePortValuesResponse\"\x00\x12P\n\x0b\x45xecuteNode\x12\x1e.connection.ExecuteNodeRequest\x1a\x1f.connection.ExecuteNodeResponse\"\x00\x12M\n\nRemoveNode\x12\x1d.connection.RemoveNodeRequest\x1a\x1e.connection.RemoveNodeResponse\"\x00\x12S\n\x0cSendResource\x12\x1f.connection.SendResourceRequest\x1a .connection.SendResourceResponse\"\x00\x12P\n\x0bGetResource\x12\x1e.connection.GetResourceRequest\x1a\x1f.connection.GetResourceResponse\"\x00\x12\\\n\x0fReleaseResource\x12\".connection.ReleaseResourceRequest\x1a#.connection.ReleaseResourceResponse\"\x00\x62\x06proto3'
)




_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='connection.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32,
  serialized_end=39,
)


_GETNODESTRUCTURESRESPONSE = _descriptor.Descriptor(
  name='GetNodeStructuresResponse',
  full_name='connection.GetNodeStructuresResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serverId', full_name='connection.GetNodeStructuresResponse.serverId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jsonData', full_name='connection.GetNodeStructuresResponse.jsonData', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=104,
)


_GETCURRENTEXISTINGNODESRESPONSE = _descriptor.Descriptor(
  name='GetCurrentExistingNodesResponse',
  full_name='connection.GetCurrentExistingNodesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serverId', full_name='connection.GetCurrentExistingNodesResponse.serverId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jsonData', full_name='connection.GetCurrentExistingNodesResponse.jsonData', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=175,
)


_CREATENODEINSTANCEREQUEST = _descriptor.Descriptor(
  name='CreateNodeInstanceRequest',
  full_name='connection.CreateNodeInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='connection.CreateNodeInstanceRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nodePath', full_name='connection.CreateNodeInstanceRequest.nodePath', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='connection.CreateNodeInstanceRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=177,
  serialized_end=248,
)


_CREATENODEINSTANCERESPONSE = _descriptor.Descriptor(
  name='CreateNodeInstanceResponse',
  full_name='connection.CreateNodeInstanceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serverId', full_name='connection.CreateNodeInstanceResponse.serverId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='connection.CreateNodeInstanceResponse.result', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errorMessage', full_name='connection.CreateNodeInstanceResponse.errorMessage', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=334,
)


_UPDATEPORTVALUESREQUEST = _descriptor.Descriptor(
  name='UpdatePortValuesRequest',
  full_name='connection.UpdatePortValuesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='connection.UpdatePortValuesRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='portValuesJson', full_name='connection.UpdatePortValuesRequest.portValuesJson', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=336,
  serialized_end=397,
)


_UPDATEPORTVALUESRESPONSE = _descriptor.Descriptor(
  name='UpdatePortValuesResponse',
  full_name='connection.UpdatePortValuesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serverId', full_name='connection.UpdatePortValuesResponse.serverId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='connection.UpdatePortValuesResponse.result', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errorMessage', full_name='connection.UpdatePortValuesResponse.errorMessage', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=399,
  serialized_end=481,
)


_EXECUTENODEREQUEST = _descriptor.Descriptor(
  name='ExecuteNodeRequest',
  full_name='connection.ExecuteNodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='connection.ExecuteNodeRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='portName', full_name='connection.ExecuteNodeRequest.portName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputPortValuesJson', full_name='connection.ExecuteNodeRequest.inputPortValuesJson', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=483,
  serialized_end=562,
)


_EXECUTENODERESPONSE = _descriptor.Descriptor(
  name='ExecuteNodeResponse',
  full_name='connection.ExecuteNodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serverId', full_name='connection.ExecuteNodeResponse.serverId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='connection.ExecuteNodeResponse.result', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errorMessage', full_name='connection.ExecuteNodeResponse.errorMessage', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='localPortValuesJson', full_name='connection.ExecuteNodeResponse.localPortValuesJson', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputPortValuesJson', full_name='connection.ExecuteNodeResponse.outputPortValuesJson', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=565,
  serialized_end=701,
)


_REMOVENODEREQUEST = _descriptor.Descriptor(
  name='RemoveNodeRequest',
  full_name='connection.RemoveNodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='connection.RemoveNodeRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=703,
  serialized_end=734,
)


_REMOVENODERESPONSE = _descriptor.Descriptor(
  name='RemoveNodeResponse',
  full_name='connection.RemoveNodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serverId', full_name='connection.RemoveNodeResponse.serverId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='connection.RemoveNodeResponse.result', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errorMessage', full_name='connection.RemoveNodeResponse.errorMessage', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=736,
  serialized_end=812,
)


_RESOURCEMETADATA = _descriptor.Descriptor(
  name='ResourceMetaData',
  full_name='connection.ResourceMetaData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='connection.ResourceMetaData.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='connection.ResourceMetaData.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=814,
  serialized_end=858,
)


_RESOURCEDATA = _descriptor.Descriptor(
  name='ResourceData',
  full_name='connection.ResourceData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='connection.ResourceData.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=860,
  serialized_end=891,
)


_SENDRESOURCEREQUEST = _descriptor.Descriptor(
  name='SendResourceRequest',
  full_name='connection.SendResourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='connection.SendResourceRequest.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='connection.SendResourceRequest.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=893,
  serialized_end=1002,
)


_SENDRESOURCERESPONSE = _descriptor.Descriptor(
  name='SendResourceResponse',
  full_name='connection.SendResourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serverId', full_name='connection.SendResourceResponse.serverId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='connection.SendResourceResponse.result', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1004,
  serialized_end=1060,
)


_GETRESOURCEREQUEST = _descriptor.Descriptor(
  name='GetResourceRequest',
  full_name='connection.GetResourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='connection.GetResourceRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove', full_name='connection.GetResourceRequest.remove', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1062,
  serialized_end=1110,
)


_GETRESOURCERESPONSE = _descriptor.Descriptor(
  name='GetResourceResponse',
  full_name='connection.GetResourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serverId', full_name='connection.GetResourceResponse.serverId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='connection.GetResourceResponse.metadata', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='connection.GetResourceResponse.data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1112,
  serialized_end=1239,
)


_RELEASERESOURCEREQUEST = _descriptor.Descriptor(
  name='ReleaseResourceRequest',
  full_name='connection.ReleaseResourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='connection.ReleaseResourceRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1241,
  serialized_end=1277,
)


_RELEASERESOURCERESPONSE = _descriptor.Descriptor(
  name='ReleaseResourceResponse',
  full_name='connection.ReleaseResourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serverId', full_name='connection.ReleaseResourceResponse.serverId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='connection.ReleaseResourceResponse.result', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errorMessage', full_name='connection.ReleaseResourceResponse.errorMessage', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1279,
  serialized_end=1360,
)

_SENDRESOURCEREQUEST.fields_by_name['metadata'].message_type = _RESOURCEMETADATA
_SENDRESOURCEREQUEST.fields_by_name['data'].message_type = _RESOURCEDATA
_GETRESOURCERESPONSE.fields_by_name['metadata'].message_type = _RESOURCEMETADATA
_GETRESOURCERESPONSE.fields_by_name['data'].message_type = _RESOURCEDATA
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
DESCRIPTOR.message_types_by_name['GetNodeStructuresResponse'] = _GETNODESTRUCTURESRESPONSE
DESCRIPTOR.message_types_by_name['GetCurrentExistingNodesResponse'] = _GETCURRENTEXISTINGNODESRESPONSE
DESCRIPTOR.message_types_by_name['CreateNodeInstanceRequest'] = _CREATENODEINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['CreateNodeInstanceResponse'] = _CREATENODEINSTANCERESPONSE
DESCRIPTOR.message_types_by_name['UpdatePortValuesRequest'] = _UPDATEPORTVALUESREQUEST
DESCRIPTOR.message_types_by_name['UpdatePortValuesResponse'] = _UPDATEPORTVALUESRESPONSE
DESCRIPTOR.message_types_by_name['ExecuteNodeRequest'] = _EXECUTENODEREQUEST
DESCRIPTOR.message_types_by_name['ExecuteNodeResponse'] = _EXECUTENODERESPONSE
DESCRIPTOR.message_types_by_name['RemoveNodeRequest'] = _REMOVENODEREQUEST
DESCRIPTOR.message_types_by_name['RemoveNodeResponse'] = _REMOVENODERESPONSE
DESCRIPTOR.message_types_by_name['ResourceMetaData'] = _RESOURCEMETADATA
DESCRIPTOR.message_types_by_name['ResourceData'] = _RESOURCEDATA
DESCRIPTOR.message_types_by_name['SendResourceRequest'] = _SENDRESOURCEREQUEST
DESCRIPTOR.message_types_by_name['SendResourceResponse'] = _SENDRESOURCERESPONSE
DESCRIPTOR.message_types_by_name['GetResourceRequest'] = _GETRESOURCEREQUEST
DESCRIPTOR.message_types_by_name['GetResourceResponse'] = _GETRESOURCERESPONSE
DESCRIPTOR.message_types_by_name['ReleaseResourceRequest'] = _RELEASERESOURCEREQUEST
DESCRIPTOR.message_types_by_name['ReleaseResourceResponse'] = _RELEASERESOURCERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'connection_pb2'
  # @@protoc_insertion_point(class_scope:connection.Empty)
  })
_sym_db.RegisterMessage(Empty)

GetNodeStructuresResponse = _reflection.GeneratedProtocolMessageType('GetNodeStructuresResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNODESTRUCTURESRESPONSE,
  '__module__' : 'connection_pb2'
  # @@protoc_insertion_point(class_scope:connection.GetNodeStructuresResponse)
  })
_sym_db.RegisterMessage(GetNodeStructuresResponse)

GetCurrentExistingNodesResponse = _reflection.GeneratedProtocolMessageType('GetCurrentExistingNodesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCURRENTEXISTINGNODESRESPONSE,
  '__module__' : 'connection_pb2'
  # @@protoc_insertion_point(class_scope:connection.GetCurrentExistingNodesResponse)
  })
_sym_db.RegisterMessage(GetCurrentExistingNodesResponse)

CreateNodeInstanceRequest = _reflection.GeneratedProtocolMessageType('CreateNodeInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENODEINSTANCEREQUEST,
  '__module__' : 'connection_pb2'
  # @@protoc_insertion_point(class_scope:connection.CreateNodeInstanceRequest)
  })
_sym_db.RegisterMessage(CreateNodeInstanceRequest)

CreateNodeInstanceResponse = _reflection.GeneratedProtocolMessageType('CreateNodeInstanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATENODEINSTANCERESPONSE,
  '__module__' : 'connection_pb2'
  # @@protoc_insertion_point(class_scope:connection.CreateNodeInstanceResponse)
  })
_sym_db.RegisterMessage(CreateNodeInstanceResponse)

UpdatePortValuesRequest = _reflection.GeneratedProtocolMessageType('UpdatePortValuesRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPORTVALUESREQUEST,
  '__module__' : 'connection_pb2'
  # @@protoc_insertion_point(class_scope:connection.UpdatePortValuesRequest)
  })
_sym_db.RegisterMessage(UpdatePortValuesRequest)

UpdatePortValuesResponse = _reflection.GeneratedProtocolMessageType('UpdatePortValuesResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPORTVALUESRESPONSE,
  '__module__' : 'connection_pb2'
  # @@protoc_insertion_point(class_scope:connection.UpdatePortValuesResponse)
  })
_sym_db.RegisterMessage(UpdatePortValuesResponse)

ExecuteNodeRequest = _reflection.GeneratedProtocolMessageType('ExecuteNodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTENODEREQUEST,
  '__module__' : 'connection_pb2'
  # @@protoc_insertion_point(class_scope:connection.ExecuteNodeRequest)
  })
_sym_db.RegisterMessage(ExecuteNodeRequest)

ExecuteNodeResponse = _reflection.GeneratedProtocolMessageType('ExecuteNodeResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTENODERESPONSE,
  '__module__' : 'connection_pb2'
  # @@protoc_insertion_point(class_scope:connection.ExecuteNodeResponse)
  })
_sym_db.RegisterMessage(ExecuteNodeResponse)

RemoveNodeRequest = _reflection.GeneratedProtocolMessageType('RemoveNodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVENODEREQUEST,
  '__module__' : 'connection_pb2'
  # @@protoc_insertion_point(class_scope:connection.RemoveNodeRequest)
  })
_sym_db.RegisterMessage(RemoveNodeRequest)

RemoveNodeResponse = _reflection.GeneratedProtocolMessageType('RemoveNodeResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVENODERESPONSE,
  '__module__' : 'connection_pb2'
  # @@protoc_insertion_point(class_scope:connection.RemoveNodeResponse)
  })
_sym_db.RegisterMessage(RemoveNodeResponse)

ResourceMetaData = _reflection.GeneratedProtocolMessageType('ResourceMetaData', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEMETADATA,
  '__module__' : 'connection_pb2'
  # @@protoc_insertion_point(class_scope:connection.ResourceMetaData)
  })
_sym_db.RegisterMessage(ResourceMetaData)

ResourceData = _reflection.GeneratedProtocolMessageType('ResourceData', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEDATA,
  '__module__' : 'connection_pb2'
  # @@protoc_insertion_point(class_scope:connection.ResourceData)
  })
_sym_db.RegisterMessage(ResourceData)

SendResourceRequest = _reflection.GeneratedProtocolMessageType('SendResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDRESOURCEREQUEST,
  '__module__' : 'connection_pb2'
  # @@protoc_insertion_point(class_scope:connection.SendResourceRequest)
  })
_sym_db.RegisterMessage(SendResourceRequest)

SendResourceResponse = _reflection.GeneratedProtocolMessageType('SendResourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDRESOURCERESPONSE,
  '__module__' : 'connection_pb2'
  # @@protoc_insertion_point(class_scope:connection.SendResourceResponse)
  })
_sym_db.RegisterMessage(SendResourceResponse)

GetResourceRequest = _reflection.GeneratedProtocolMessageType('GetResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESOURCEREQUEST,
  '__module__' : 'connection_pb2'
  # @@protoc_insertion_point(class_scope:connection.GetResourceRequest)
  })
_sym_db.RegisterMessage(GetResourceRequest)

GetResourceResponse = _reflection.GeneratedProtocolMessageType('GetResourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRESOURCERESPONSE,
  '__module__' : 'connection_pb2'
  # @@protoc_insertion_point(class_scope:connection.GetResourceResponse)
  })
_sym_db.RegisterMessage(GetResourceResponse)

ReleaseResourceRequest = _reflection.GeneratedProtocolMessageType('ReleaseResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _RELEASERESOURCEREQUEST,
  '__module__' : 'connection_pb2'
  # @@protoc_insertion_point(class_scope:connection.ReleaseResourceRequest)
  })
_sym_db.RegisterMessage(ReleaseResourceRequest)

ReleaseResourceResponse = _reflection.GeneratedProtocolMessageType('ReleaseResourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _RELEASERESOURCERESPONSE,
  '__module__' : 'connection_pb2'
  # @@protoc_insertion_point(class_scope:connection.ReleaseResourceResponse)
  })
_sym_db.RegisterMessage(ReleaseResourceResponse)



_CONNECTIONGRPC = _descriptor.ServiceDescriptor(
  name='ConnectionGrpc',
  full_name='connection.ConnectionGrpc',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1363,
  serialized_end=2175,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetNodeStructures',
    full_name='connection.ConnectionGrpc.GetNodeStructures',
    index=0,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_GETNODESTRUCTURESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCurrentExistingNodes',
    full_name='connection.ConnectionGrpc.GetCurrentExistingNodes',
    index=1,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_GETCURRENTEXISTINGNODESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateNodeInstance',
    full_name='connection.ConnectionGrpc.CreateNodeInstance',
    index=2,
    containing_service=None,
    input_type=_CREATENODEINSTANCEREQUEST,
    output_type=_CREATENODEINSTANCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdatePortValues',
    full_name='connection.ConnectionGrpc.UpdatePortValues',
    index=3,
    containing_service=None,
    input_type=_UPDATEPORTVALUESREQUEST,
    output_type=_UPDATEPORTVALUESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExecuteNode',
    full_name='connection.ConnectionGrpc.ExecuteNode',
    index=4,
    containing_service=None,
    input_type=_EXECUTENODEREQUEST,
    output_type=_EXECUTENODERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveNode',
    full_name='connection.ConnectionGrpc.RemoveNode',
    index=5,
    containing_service=None,
    input_type=_REMOVENODEREQUEST,
    output_type=_REMOVENODERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendResource',
    full_name='connection.ConnectionGrpc.SendResource',
    index=6,
    containing_service=None,
    input_type=_SENDRESOURCEREQUEST,
    output_type=_SENDRESOURCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetResource',
    full_name='connection.ConnectionGrpc.GetResource',
    index=7,
    containing_service=None,
    input_type=_GETRESOURCEREQUEST,
    output_type=_GETRESOURCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReleaseResource',
    full_name='connection.ConnectionGrpc.ReleaseResource',
    index=8,
    containing_service=None,
    input_type=_RELEASERESOURCEREQUEST,
    output_type=_RELEASERESOURCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONNECTIONGRPC)

DESCRIPTOR.services_by_name['ConnectionGrpc'] = _CONNECTIONGRPC

# @@protoc_insertion_point(module_scope)
